==> icinga2-2.9.2v0.tgz: share/doc/icinga2/markdown/01-about.md <==
# About Icinga 2 <a id="about-icinga2"></a>

## What is Icinga 2?  <a id="what-is-icinga2"></a>

Icinga 2 is an open source monitoring system which checks the availability of
your network resources, notifies users of outages and generates performance
data for reporting.

Scalable and extensible, Icinga 2 can monitor large, complex environments across
multiple locations.

## Licensing  <a id="licensing"></a>

Icinga 2 and the Icinga 2 documentation are licensed under the terms of the GNU
General Public License Version 2. You will find a copy of this license in the
LICENSE file included in the source package.

## Support  <a id="support"></a>

Check the project website at [icinga.com](https://www.icinga.com) for status updates. Join the
[community channels](https://www.icinga.com/community/get-involved/) for questions
or ask an Icinga partner for [professional support](https://www.icinga.com/services/support/).

## Contribute  <a id="contribute"></a>

There are many ways to contribute to Icinga -- whether it be sending patches,
testing, reporting bugs or reviewing and updating the documentation. Every
contribution is appreciated!

Please continue reading in the [Contributing chapter](https://github.com/Icinga/icinga2/blob/master/CONTRIBUTING.md).

### Icinga 2 Development <a id="development-info"></a>

The Git repository is located on [GitHub](https://github.com/Icinga/icinga2).

Icinga 2 is written in C++ and can be built on Linux/Unix and Windows.
Read more about development builds in the [INSTALL.md](https://github.com/Icinga/icinga2/blob/master/INSTALL.md)
file.

## What's New <a id="whats-new"></a>

The Icinga 2 Changelog is located [here](https://github.com/Icinga/icinga2/blob/master/CHANGELOG.md).
Please follow our release announcements on [icinga.com](https://www.icinga.com/blog/) too.

==> icinga2-2.10.4v0.tgz: share/doc/icinga2/markdown/01-about.md <==
# About Icinga 2 <a id="about-icinga2"></a>

## What is Icinga 2?  <a id="what-is-icinga2"></a>

Icinga 2 is an open source monitoring system which checks the availability of
your network resources, notifies users of outages and generates performance
data for reporting.

Scalable and extensible, Icinga 2 can monitor large, complex environments across
multiple locations.

## Licensing  <a id="licensing"></a>

Icinga 2 and the Icinga 2 documentation are licensed under the terms of the GNU
General Public License Version 2. You will find a copy of this license in the
LICENSE file included in the source package.

## Support  <a id="support"></a>

Check the project website at [icinga.com](https://icinga.com) for status updates. Join the
[community channels](https://icinga.com/community/) for questions
or ask an Icinga partner for [professional support](https://icinga.com/services/support/).

## Contribute  <a id="contribute"></a>

There are many ways to contribute to Icinga -- whether it be sending patches,
testing, reporting bugs or reviewing and updating the documentation. Every
contribution is appreciated!

Please continue reading in the [Contributing chapter](https://github.com/Icinga/icinga2/blob/master/CONTRIBUTING.md).

### Icinga 2 Development <a id="development-info"></a>

The Git repository is located on [GitHub](https://github.com/Icinga/icinga2).

Icinga 2 is written in C++ and can be built on Linux/Unix and Windows.
Read more about development builds in the [INSTALL.md](https://github.com/Icinga/icinga2/blob/master/INSTALL.md)
file.

## What's New <a id="whats-new"></a>

The Icinga 2 Changelog is located [here](https://github.com/Icinga/icinga2/blob/master/CHANGELOG.md).
Please follow our release announcements on [icinga.com](https://icinga.com/blog/) too.
